@@ -1,6 +1,17 @@
 #pragma once
 #ifndef __RxODE_H__
 #define __RxODE_H__
+#define STRICT_R_HEADERS
+
+#include <float.h>
+#include <stdio.h>
+#include <stdarg.h>
+#include <R.h>
+#include <Rinternals.h>
+#include <Rmath.h>
+#include <stdbool.h>
+#include <R_ext/Rdynload.h>
+
 #define isDose(evid) ((evid) == 3 || (evid) >= 100)
 #define isObs(evid) ((evid) == 0 || (evid) == 2 || ((evid) >= 9 && (evid) <= 99))
 
@@ -9,32 +20,24 @@
 #define getAdvan(idx) ind->solve + (op->neq + op->nlin)*(idx) + op->neq
 #define getSolve(idx) ind->solve + (op->neq + op->nlin)*(idx)
 
-
-
 #ifdef _isRxODE_
 
 #define max2( a , b )  ( (a) > (b) ? (a) : (b) )
 #define isSameTime(xout, xp) ((xout)-(xp) <= DBL_EPSILON*max2(fabs(xout),fabs(xp)))
 
 #else
-
 #if defined(__cplusplus)
 #include "RxODE_RcppExports.h"
 #endif
 
 #endif // _isRxODE_
 
+
+
 #if defined(__cplusplus)
 extern "C" {
 #endif
 
-#include <stdio.h>
-#include <stdarg.h>
-#include <R.h>
-#include <Rinternals.h>
-#include <Rmath.h>
-#include <stdbool.h>
-#include <R_ext/Rdynload.h>
 
 typedef void (*t_dydt)(int *neq, double t, double *A, double *DADT);
 typedef void (*t_calc_jac)(int *neq, double t, double *A, double *JAC, unsigned int __NROWPD__);
@@ -231,6 +234,8 @@ typedef struct {
   double curShift;
   double *simIni;
   int isIni;
+  int _update_par_ptr_in;
+  int badIni;
 } rx_solving_options_ind;
 
 typedef struct {
@@ -310,7 +315,7 @@ void rxOptionsIniEnsure(int mx);
 
 void rxUpdateFuns(SEXP trans);
 
-#define _eps sqrt(DOUBLE_EPS)
+#define _eps sqrt(DBL_EPSILON)
 
 static inline double erfinv(double x)  __attribute__((unused));
 static inline double erfinv(double x) {
@@ -680,6 +685,12 @@ static inline void lineNull(vLines *sbb) {
   sbb->o  = 0;
 }
 
+
+extern rx_solve rx_global;
+extern rx_solving_options op_global;
+extern rx_solving_options_ind *inds_global;
+
+
 #endif
 #if defined(__cplusplus)
 }
