@@ -1,78 +1,78 @@
 #include <time.h>
 #include <stdlib.h>
+unsigned long int __timeId=0;
 void writeHeader(const char *md5, const char *extra) {
-unsigned long int timeId=0;
-sAppend(&sbOut, "#define _getRxSolve_ _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define simeps _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define simeta _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _solveData _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _assign_ptr _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _rxRmModelLib _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _rxGetModelLib _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _old_c _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _ptrid _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _rxIsCurrentC _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _sumPS _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _prodPS _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _prodType _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _sumType _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _update_par_ptr _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _getParCov _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define linCmtA _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define linCmtC _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define linCmtB _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _RxODE_rxAssignPtr _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _rxQr _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define phi _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define logit _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define expit _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammap _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammaq _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define lowergamma _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define uppergamma _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammapInv _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammapDer _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammapInva _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammaqInv _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define gammaqInva _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxnorm _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxnormV _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxbinom _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxcauchy _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxchisq _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxexp _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxf _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxgeom _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxgamma _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxbeta _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxpois _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxt_ _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxunif _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rxweibull _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rinorm _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rinormV _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define ribinom _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define ricauchy _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define richisq _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define riexp _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rif _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rigeom _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rigamma _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define ribeta _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define ripois _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define rit_ _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define riunif _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define riweibull _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _compareFactorVal _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _sum _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _sign _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _prod _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _max _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _min _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _transit4P _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _transit3P _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _assignFuns0 _rx%s%s%ld\n", extra, md5, timeId++);
-sAppend(&sbOut, "#define _assignFuns _rx%s%s%ld\n", extra, md5, timeId++);
+sAppend(&sbOut, "#define _getRxSolve_ _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define simeps _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define simeta _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _solveData _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _assign_ptr _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _rxRmModelLib _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _rxGetModelLib _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _old_c _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _ptrid _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _rxIsCurrentC _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _sumPS _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _prodPS _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _prodType _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _sumType _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _update_par_ptr _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _getParCov _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define linCmtA _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define linCmtC _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define linCmtB _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _RxODE_rxAssignPtr _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _rxQr _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define phi _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define logit _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define expit _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammap _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammaq _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define lowergamma _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define uppergamma _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammapInv _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammapDer _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammapInva _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammaqInv _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define gammaqInva _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxnorm _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxnormV _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxbinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxcauchy _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxchisq _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxexp _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxf _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxgeom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxgamma _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxbeta _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxpois _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxt_ _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxunif _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxweibull _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rinorm _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rinormV _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define ribinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define ricauchy _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define richisq _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define riexp _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rif _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rigeom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rigamma _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define ribeta _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define ripois _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rit_ _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define riunif _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define riweibull _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _compareFactorVal _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _sum _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _sign _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _prod _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _max _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _min _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _transit4P _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _transit3P _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _assignFuns0 _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _assignFuns _rx%s%s%ld\n", extra, md5, __timeId++);
 }
 void writeBody() {
 sAppendN(&sbOut, "_getRxSolve_t _getRxSolve_;\n", 28);
