@@ -1,3 +1,4 @@
+#define STRICT_R_HEADER
 #include <R.h>
 #include <Rversion.h>
 #include <Rinternals.h>
@@ -17,27 +18,7 @@
 #define _(String) (String)
 #endif
 
-#ifdef _OPENMP
-#include <pthread.h>
-#include <omp.h>
-#else
-
-int omp_get_num_procs(){
-  return 1;
-}
-
-int omp_get_thread_limit(){
-  return 1;
-}
-
-int omp_get_max_threads(){
-  return 1;
-}
-
-int omp_get_thread_num(){
-  return 0;
-}
-#endif
+#include "rxomp.h"
 
 // Much of this comes from data.table, with references to where it came from
 
@@ -289,8 +270,8 @@ static bool sort_ugrp(uint8_t *x, const int n)
 //  - modified so that radix_r is 0 order not 1 order like R (since we are using it in C)
 extern "C" void radix_r(const int from, const int to, const int radix,
 	     rx_solving_options_ind *ind, rx_solve *rx) {
-  uint8_t **key = rx->keys[omp_get_thread_num()];
-  int nradix = rx->nradix[omp_get_thread_num()];
+  uint8_t **key = rx->keys[0];
+  int nradix = rx->nradix[0];
   int *anso = ind->ix;
   const int my_n = to-from+1;
   if (my_n==1) {  // minor TODO: batch up the 1's instead in caller (and that's only needed when retgrp anyway)
@@ -376,7 +357,7 @@ extern "C" void radix_r(const int from, const int to, const int radix,
     // This thread-private stack alloc has no chance of false sharing and gives omp and compiler best chance.
     // RxODE change use std::fill_n();  In my experience sometimes = {0}; doesn't always fill 0.
     std::fill_n(my_counts, 256, 0);
-    //uint8_t * my_ugrp = rx->UGRP + omp_get_thread_num()*256;  // uninitialized is fine; will use the first ngrp items. Only used if sortType==0
+    //uint8_t * my_ugrp = rx->UGRP + 0*256;  // uninitialized is fine; will use the first ngrp items. Only used if sortType==0
     // TODO: ensure my_counts, my_grp and my_tmp below are cache line aligned on both Linux and Windows.
     const uint8_t * my_key = key[radix]+from;
     int ngrp = 0;          // number of groups (items in ugrp[]). Max value 256 but could be uint8_t later perhaps if 0 is understood as 1.
@@ -403,7 +384,7 @@ extern "C" void radix_r(const int from, const int to, const int radix,
       // Use https://github.com/Rdatatable/data.table/blob/be6c1fc66a411211c4ca944702c1cab7739445f3/src/forder.c#L991
       // since sortType=1
       for (int i=0, sum=0; i<256; i++) { int tmp=my_counts[i]; my_starts[i]=my_starts_copy[i]=sum; sum+=tmp; ngrp+=(tmp>0);}  // cumulate through 0's too (won't be used)
-      int * my_TMP = rx->TMP + omp_get_thread_num()*UINT16_MAX; // Allocated up front to save malloc calls which i) block internally and ii) could fail
+      int * my_TMP = rx->TMP; // Allocated up front to save malloc calls which i) block internally and ii) could fail
       // Modified nalast not used since NAs cannot occur for a good sort of times
       if (radix==0) {
 	// anso contains 1:n so skip reading and copying it. Only happens when nrow<65535. Saving worth the branch (untested) when user repeatedly calls a small-n small-cardinality order.
